@@ -292,11 +292,12 @@ class JSON2EDCLineageFiles:
         print("looking for attribute >%s<" % attribute)
         for entity in entities:
             entity_attributes = self.get_attributes(entity)
-            print("Entity >%s< #attributes >%d<" % (entity, len(entity_attributes)))
+            # print("Entity >%s< #attributes >%d<" % (entity, len(entity_attributes)))
             for entity_attribute in entity_attributes:
                 if entity_attribute["uid"] == attribute:
                     print("Found: entity_attribute >%s< is named >%s<" % (entity_attribute["uid"], entity_attribute["name"]))
                     return True, entity, entity_attribute["name"]
+        print("NOT FOUND: attribute >%s< in entity list >%s<", attribute, str(entities))
         return False, None, None
 
     def get_attributes(self, entity):
